@@ -346,7 +346,7 @@ class UCubeClientAsync(UCubeClient):
 
         """
         replace_kwargs = {
-            "post_slug": post_slug
+            "{post_slug}": post_slug
         }
         url = self.replace(self._single_post_url, **replace_kwargs)
         async with self.web_session.get(url=url, headers=self._headers) as resp:
